@@ -1584,7 +1584,7 @@ class Compiler:
         e.vars[iterated_element_name] = e.sp
         # type iterated element
         iterable_type = self.type_checker.get_expression_type(node.iter, e)
-        if type(iterable_type) == t.List:
+        if isinstance(iterable_type, (t.List, t.Set)):
             e.types[iterated_element_name] = iterable_type.element_type
         elif type(iterable_type) == t.Dict:
             raise E.CompilerException("Dictionary iteration not yet supported", node.iter.lineno)
