@@ -459,6 +459,7 @@ base_types = [
 polymorphic_types = [
     "Dict",
     "List",
+    "Set",
     "Callable",
     "Contract",
 ]
@@ -521,11 +522,11 @@ class TypeParser:
 
     def parse_list(self, list_: ast.Subscript, e, annotation):
         param_type = self.parse(list_.slice, e)
-        return List(param_type)
+        return List(param_type, annotation)
 
     def parse_set(self, set_: ast.Subscript, e, annotation):
         param_type = self.parse(set_.slice, e)
-        return Set(param_type)
+        return Set(param_type, annotation)
 
     def parse_subscript(self, subscript: ast.Subscript, e, annotation: Optional[str] = None, lineno = 0):
         if subscript.value.id == "Dict":
